@@ -1,7 +1,9 @@
 #coding=utf-8
-
+import os
 coding="utf-8"
 def bread(filepath):
+    if type(filepath) not in [str, bytes, os.PathLike]:
+        raise Exception(f"error filepath: {filepath}")
     with open(filepath, 'rb') as file:
         s = file.read()
     return s
@@ -38,4 +40,10 @@ def fread_c(filepath, coding = 'utf-8'):
     s = bread(filepath)
     return decode_c(s, coding)
 
-pass
\ No newline at end of file
+pass
+
+def fwrite(content, filepath, mode = 'w'):
+    with open(filepath, mode) as f:
+        f.write(content)
+
+pass
